California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 021 - ESTABLISHES $18 ANNUAL VEHICLE LICENSE SURCHARGE TO HELP FUND STATE PARKS AND WILDLIFE PROGRAMS AND GRANTS FREE ADMISSION TO ALL STATE PARKS TO SURCHARGED VEHICLES. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1322009 | YES ON 21, CALIFORNIANS FOR STATE PARKS AND WILDLIFE CONSERVATION, SPONSORED BY CONSERVATION AND STATE PARKS ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1272719 | CONSERVATION ACTION FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1328329 | STOP THE CAR TAX SCAM - NO ON PROPOSITION 21, A COALITION INCLUDING THE ALLIANCE OF AUTOMOBILE MANUFACTURERS, INC. | OPPOSE